Struct pixels::PixelsContext [−][src]
pub struct PixelsContext {
pub device: Device,
pub queue: Queue,
pub texture: Texture,
pub texture_extent: Extent3d,
pub texture_format: TextureFormat,
pub texture_format_size: f32,
pub scaling_renderer: ScalingRenderer,
// some fields omitted
}Provides the internal state for custom shaders.
A reference to this struct is given to the render_function closure when using
Pixels::render_with.
Fields
device: DeviceThe Device allows creating GPU resources.
queue: QueueThe Queue provides access to the GPU command queue.
texture: TextureThis is the texture that your raw data is copied to by Pixels::render or
Pixels::render_with.
texture_extent: Extent3dProvides access to the texture size.
texture_format: TextureFormattexture_format_size: f32Defines the “data rate” for the raw texture data. This is effectively the “bytes per pixel” count.
Compressed textures may have less than one byte per pixel.
scaling_renderer: ScalingRendererA default renderer to scale the input texture to the screen size.