ScalingRenderer

Struct ScalingRenderer 

pub struct ScalingRenderer { /* private fields */ }
The default renderer that scales your frame to the screen size.

Implementations

Source

impl ScalingRenderer

pub fn render(&self, encoder: &mut CommandEncoder, render_target: &TextureView)

Draw the pixel buffer to the render target.

pub fn clip_rect(&self) -> (u32, u32, u32, u32)

Get the clipping rectangle for the scaling renderer.

This rectangle defines the inner bounds of the surface texture, without the border.