pub enum ScalingMode {
PixelPerfect,
Fill,
}Expand description
The scaling mode controls the scaling behavior of renderers::ScalingRenderer.
Variants
PixelPerfect
The buffer is scaled up, if needed, to the nearest integer multiple of the buffer size.
Fill
Fill the screen while preserving aspect ratio. The renderer effectively scales the buffer to the nearest integer multiple first, then linearly interpolates to fit.